# Animation Options

Animation commands are used to create and control object-based and image-based animations in the viewport.

## Classes

### AnimationOptions

```{eval-rst}
.. autoclass:: abaqus.Animation.AnimationOptions.AnimationOptions
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### AnimationSession

```{eval-rst}
.. autoclass:: abaqus.Animation.AnimationSession.AnimationSession
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### AVIOptions

```{eval-rst}
.. autoclass:: abaqus.Animation.AVIOptions.AVIOptions
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ImageAnimation

```{eval-rst}
.. autoclass:: abaqus.Animation.ImageAnimation.ImageAnimation
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ImageAnimationOptions

```{eval-rst}
.. autoclass:: abaqus.Animation.ImageAnimationOptions.ImageAnimationOptions
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### Movie

```{eval-rst}
.. autoclass:: abaqus.Animation.Movie.Movie
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### QuickTimeOptions

```{eval-rst}
.. autoclass:: abaqus.Animation.QuickTimeOptions.QuickTimeOptions
    :members:
    :special-members: __init__
```
